pydae - DAE equations in Python
===============================

.. image:: logo/logo_text.svg
   :width: 675px
   :align: center



**pydae** is an open source (MIT) collection of Python functions useful
for analysis and simulation of Diferential Algebraic Equations (DAE) systems.

View `source code`_ of pydae!

.. _`source code`: https://github.com/pydae/pydae



Some of its features are:

* State space symbolic definition of the DAE system using sympy `sympy`_.
* Jacobians of the DAE system obtention.
* DAE solver for time domain simulation.
* Small signal analysis tools.
* Numba implemented functions.
* A collection of DAE models for power systems.



Contents
--------


.. toctree::
    :maxdepth: 2

    about
    getting_started
    user_guide 
    ss.ipynb 
    ssa
    examples/pendulum_dae.ipynb
    examples/pendulum_sim.ipynb
    grid_urisi/index
